[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://github.com/kuflow/kuflow-sdk-python/blob/master/LICENSE)
[![Python](https://img.shields.io/pypi/pyversions/kuflow-rest.svg)](https://pypi.org/project/kuflow-rest)
[![PyPI](https://img.shields.io/pypi/v/kuflow-rest.svg)](https://pypi.org/project/kuflow-rest)

# KuFlow Rest

This is a client for the KuFlow API Rest that allows you to interact with our API in a comfortable way in the creation of your workers and tools.

## Documentation

More detailed docs are available in the [documentation pages](https://docs.kuflow.com/developers/).

## Contributing

We are happy to receive your help and comments, together we will dance a wonderful KuFlow. Please review our [contribution guide](CONTRIBUTING.md).

## License

[MIT License](https://github.com/kuflow/kuflow-sdk-python/blob/master/LICENSE)
